Module dfont

Module dfont 

Structs

DFont
A representation of everything we need to know about a font for diffenator purposes

Functions

shared_axes
Compare two fonts and return the axes and instances they have in common