Re-exports
pub use crate::structs::Difference;pub use crate::structs::GlyphDiff;
Modules
Constants
- DEFAULT_
GLYPHS_ FONT_ SIZE - DEFAULT_
GLYPHS_ THRESHOLD - DEFAULT_
GRAY_ FUZZ - Gray pixels which differ by less than this amount are considered the same
- DEFAULT_
WORDS_ FONT_ SIZE - DEFAULT_
WORDS_ THRESHOLD - Number of differing pixels after which two images are considered different
Functions
- test_
font_ words - Compare two fonts by rendering a list of words and comparing the images