test_font_words

Function test_font_words 

pub fn test_font_words(
    font_a: &DFont,
    font_b: &DFont,
    custom_inputs: &[WordList],
) -> BTreeMap<String, Vec<Difference>>
Compare two fonts by rendering a list of words and comparing the images

Word lists are gathered for all scripts which are supported by both fonts. The return value is a BTreeMap where each key is a script tag and the value is a list of Difference objects.