Renderer

Struct Renderer 

pub struct Renderer<'a> { /* private fields */ }

Implementations

Source

impl<'a> Renderer<'a>

pub fn new( dfont: &'a DFont, font_size: f32, direction: Option<Direction>, script: Option<Script>, ) -> Self

Create a new renderer for a font

Direction and script are needed for correct shaping; no automatic detection is done.

pub fn string_to_positioned_glyphs( &mut self, string: &str, ) -> Option<(String, Vec<Command>)>

Render a string to a series of commands

The commands can be used to render the string to an image. This routine also returns a serialized buffer that can be used both for debugging purposes and also to detect glyph sequences which have been rendered already (which helps to speed up the comparison).

pub fn render_positioned_glyphs(&mut self, pen_buffer: &[Command]) -> GrayImage

Render a series of commands to an image

This routine takes a series of commands returned from [string_to_positioned_glyphs] and renders them to an image.