Module utils

Module utils 

Structs

RecordingPen

Functions

count_differences
Compare two images and return the count of differing pixels
make_same_size
Make two images the same size by padding the smaller one with white