make_same_size

Function make_same_size 

pub fn make_same_size(
    image_a: GrayImage,
    image_b: GrayImage,
) -> (GrayImage, GrayImage)
Make two images the same size by padding the smaller one with white

The smaller image is anchored to the top left corner of the larger image.