WordList

Struct WordList 

pub struct WordList { /* private fields */ }
A list of words, with optional additional metadata.

Implementations

Source

impl WordList

pub fn load( path: impl AsRef<Path>, metadata_path: impl AsRef<Path>, ) -> Result<WordList, WordListError>

Load a word list from a file.

The file is expected to contain one word per line. The word list may also be accompanied by a metadata TOML file. A fully specified metadata file may look like this:

name = "diffenator_latin"
script = "Latn"
pub fn load_without_metadata( path: impl AsRef<Path>, ) -> Result<WordList, WordListError>

Load a word list from a file.

The file is expected to contain one word per line. Always prefer WordList::load if metadata is available.

pub fn define( name: impl Into<String>, words: impl IntoIterator<Item = impl Into<String>>, ) -> WordList

Create a new word list from an iterable.

Metadata is unspecified.

pub fn name(&self) -> &str

Get the name of the word list.

pub fn script(&self) -> Option<&str>

Get the script of the word list, if known.

The script is expected to be a ISO 15924 four-letter capitalised code, but this is only guaranteed for built-in word lists.

pub fn language(&self) -> Option<&str>

Get the language of the word list, if known.

The language is expected to be a ISO 639-1 two-letter code, but this is only guaranteed for built-in word lists.

pub fn iter(&self) -> WordListIter<'_>

Iterate through the word list.

pub fn len(&self) -> usize

Get how many words there are in the word list.

pub fn is_empty(&self) -> bool

Returns true if there are no words in the word list.

Source

impl WordList

pub fn par_iter(&self) -> ParWordListIter<'_>

Iterate through the word list in parallel with rayon.