pub struct Difference {
pub word: String,
pub buffer_a: String,
pub buffer_b: Option<String>,
pub differing_pixels: usize,
pub ot_features: String,
pub lang: String,
}Expand description
Represents a difference between two renderings, whether words or glyphs
Fields
word: StringThe text string which was rendered
buffer_a: StringA string representation of the shaped buffer in the first font
buffer_b: Option<String>A string representation of the shaped buffer in the second font, if different
differing_pixels: usizeThe number of differing pixels
ot_features: StringThe OpenType features applied to the text
lang: StringThe OpenType language tag applied to the text