pub struct DFont {
pub backing: Vec<u8>,
pub location: Vec<VariationSetting>,
pub normalized_location: Location,
pub codepoints: HashSet<u32>,
}Expand description
A representation of everything we need to know about a font for diffenator purposes
Fields
backing: Vec<u8>The font binary data
location: Vec<VariationSetting>The location of the font we are interested in diffing
normalized_location: LocationThe normalized location of the font
codepoints: HashSet<u32>The set of encoded codepoints in the font
Implementations
Sourceimpl DFont
impl DFont
Sourcepub fn normalize_location(&mut self)
pub fn normalize_location(&mut self)
Normalize the location
This method must be called after the location is changed. (It’s that or getters and setters, and nobody wants that.)
Sourcepub fn set_location(&mut self, variations: &str) -> Result<(), String>
pub fn set_location(&mut self, variations: &str) -> Result<(), String>
Set the location of the font given a user-specified location string
Sourcepub fn set_instance(&mut self, instance: &str) -> Result<(), String>
pub fn set_instance(&mut self, instance: &str) -> Result<(), String>
Set the location of the font to a given named instance
pub fn fontref(&self) -> FontRef<'_>
pub fn family_name(&self) -> String
pub fn style_name(&self) -> String
Sourcepub fn axis_info(&self) -> HashMap<String, (f32, f32, f32)>
pub fn axis_info(&self) -> HashMap<String, (f32, f32, f32)>
The axes of the font
Returns a map from axis tag to (min, default, max) values
Sourcepub fn supported_scripts(&self) -> HashSet<String>
pub fn supported_scripts(&self) -> HashSet<String>
Returns a list of scripts where the font has at least one encoded character from that script.