Module render

Module render 

Re-exports

pub use crate::structs::Difference;
pub use crate::structs::GlyphDiff;

Modules

encodedglyphs
renderer
utils
wordlists

Constants

DEFAULT_GLYPHS_FONT_SIZE
DEFAULT_GLYPHS_THRESHOLD
DEFAULT_GRAY_FUZZ
Gray pixels which differ by less than this amount are considered the same
DEFAULT_WORDS_FONT_SIZE
DEFAULT_WORDS_THRESHOLD
Number of differing pixels after which two images are considered different

Functions

test_font_words
Compare two fonts by rendering a list of words and comparing the images