Module encodedglyphs

Module encodedglyphs 

Re-exports

pub use crate::structs::CmapDiff;
pub use crate::structs::EncodedGlyph;

Enums

Direction
Defines the direction in which text is to be read.

Functions

modified_encoded_glyphs
Render the encoded glyphs common to both fonts, and return any differences