pub struct Renderer<'a> { /* private fields */ }Implementations
Sourceimpl<'a> Renderer<'a>
impl<'a> Renderer<'a>
Sourcepub fn new(
dfont: &'a DFont,
font_size: f32,
direction: Option<Direction>,
script: Option<Script>,
) -> Self
pub fn new( dfont: &'a DFont, font_size: f32, direction: Option<Direction>, script: Option<Script>, ) -> Self
Create a new renderer for a font
Direction and script are needed for correct shaping; no automatic detection is done.
Sourcepub fn string_to_positioned_glyphs(
&mut self,
string: &str,
) -> Option<(String, Vec<Command>)>
pub fn string_to_positioned_glyphs( &mut self, string: &str, ) -> Option<(String, Vec<Command>)>
Render a string to a series of commands
The commands can be used to render the string to an image. This routine also returns a serialized buffer that can be used both for debugging purposes and also to detect glyph sequences which have been rendered already (which helps to speed up the comparison).
Sourcepub fn render_positioned_glyphs(&mut self, pen_buffer: &[Command]) -> GrayImage
pub fn render_positioned_glyphs(&mut self, pen_buffer: &[Command]) -> GrayImage
Render a series of commands to an image
This routine takes a series of commands returned from [string_to_positioned_glyphs] and renders them to an image.