Module utils
diffenator3_
lib
1.1.2
Module utils
Module Items
Structs
Functions
In diffenator3_
lib::
render
diffenator3_lib
::
render
Module
utils
Structs

Recording
Pen
Functions

count_
differences
Compare two images and return the count of differing pixels
make_
same_
size
Make two images the same size by padding the smaller one with white