pub struct WordList { /* private fields */ }Expand description
A list of words, with optional additional metadata.
Implementations
Sourceimpl WordList
impl WordList
Sourcepub fn load(
path: impl AsRef<Path>,
metadata_path: impl AsRef<Path>,
) -> Result<WordList, WordListError>
pub fn load( path: impl AsRef<Path>, metadata_path: impl AsRef<Path>, ) -> Result<WordList, WordListError>
Load a word list from a file.
The file is expected to contain one word per line. The word list may also be accompanied by a metadata TOML file. A fully specified metadata file may look like this:
name = "diffenator_latin"
script = "Latn"Sourcepub fn load_without_metadata(
path: impl AsRef<Path>,
) -> Result<WordList, WordListError>
pub fn load_without_metadata( path: impl AsRef<Path>, ) -> Result<WordList, WordListError>
Load a word list from a file.
The file is expected to contain one word per line.
Always prefer WordList::load if metadata is available.
Sourcepub fn define(
name: impl Into<String>,
words: impl IntoIterator<Item = impl Into<String>>,
) -> WordList
pub fn define( name: impl Into<String>, words: impl IntoIterator<Item = impl Into<String>>, ) -> WordList
Create a new word list from an iterable.
Metadata is unspecified.
Sourcepub fn script(&self) -> Option<&str>
pub fn script(&self) -> Option<&str>
Get the script of the word list, if known.
The script is expected to be a ISO 15924 four-letter capitalised code, but this is only guaranteed for built-in word lists.
Sourcepub fn language(&self) -> Option<&str>
pub fn language(&self) -> Option<&str>
Get the language of the word list, if known.
The language is expected to be a ISO 639-1 two-letter code, but this is only guaranteed for built-in word lists.
Sourcepub fn iter(&self) -> WordListIter<'_>
pub fn iter(&self) -> WordListIter<'_>
Iterate through the word list.